@@ -84,6 +84,10 @@ int Help()
     TEXTOUT("                    Apply the display transformation (XSL)");
     TEXTOUT("");
 
+    TEXTOUT("--List");
+    TEXTOUT("                    List files analyzed.");
+    TEXTOUT("");
+
     TEXTOUT("Watch folder:");
     TEXTOUT("--WatchFolders-List, -wfl");
     TEXTOUT("                    List the folder watched");
@@ -263,7 +267,7 @@ int Help_Xslt()
 //---------------------------------------------------------------------------
 int Version()
 {
-    TEXTOUT("MediaConch Command Line Interface 17.01.1");
+    TEXTOUT("MediaConch Command Line Interface 17.05");
 
     return CLI_RETURN_FINISH;
 }
