@@ -596,7 +596,7 @@ int Core::checker_list(int user, std::vector<long>& vec, std::string& err)
 }
 
 //---------------------------------------------------------------------------
-int Core::remove_report(int user, const std::vector<long>& files, std::string& err)
+int Core::checker_clear(int user, const std::vector<long>& files, std::string& err)
 {
     if (!get_db())
     {
@@ -605,13 +605,27 @@ int Core::remove_report(int user, const std::vector<long>& files, std::string& e
     }
 
     int ret = 0;
-    db_mutex.Enter();
-    for (size_t i = 0; i < files.size(); ++i)
+    if (files.size())
     {
-        if (db->remove_report(user, files[i], err) < 0)
+        db_mutex.Enter();
+        for (size_t i = 0; i < files.size(); ++i)
+        {
+            if (get_db()->remove_report(user, files[i], err) < 0)
+                ret = -1;
+            if (get_db()->remove_file(user, files[i], err) < 0)
+                ret = -1;
+        }
+        db_mutex.Leave();
+    }
+    else
+    {
+        db_mutex.Enter();
+        if (get_db()->remove_all_reports(user, err) < 0)
             ret = -1;
+        if (get_db()->remove_all_files(user, err) < 0)
+            ret = -1;
+        db_mutex.Leave();
     }
-    db_mutex.Leave();
 
     return ret;
 }
