@@ -63,6 +63,8 @@ public:
                                               std::string& options,
                                               bool& analyzed, bool& has_error, std::string& error_log, std::string& err) = 0;
     virtual bool file_is_analyzed(int user, long id, std::string& err) = 0;
+    virtual int  remove_file(int user, long file_id, std::string& err) = 0;
+    virtual int  remove_all_files(int user, std::string& err) = 0;
     virtual int  add_file_generated_id(int user, long source_id, long generated_id, std::string& err) = 0;
     virtual int  update_file_analyzed(int user, long id, std::string& err, bool analyzed=true) = 0;
     virtual int  update_file_error(int user, long id, std::string& err,
@@ -74,6 +76,7 @@ public:
                              const std::string& report, MediaConchLib::compression,
                              int mil_version, std::string& err) = 0;
     virtual int  remove_report(int user, long file_id, std::string& err) = 0;
+    virtual int  remove_all_reports(int user, std::string& err) = 0;
     virtual int  get_report(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
                             const std::string& options,
                             std::string& report, MediaConchLib::compression&, std::string& err) = 0;
