@@ -18,11 +18,23 @@
 #include <vector>
 #include <map>
 #include <bitset>
+#ifdef MEDIAINFO_DLL_RUNTIME
+    #include "MediaInfoDLL/MediaInfoDLL.h"
+    #define MediaInfoNameSpace MediaInfoDLL
+#elif defined MEDIAINFO_DLL_STATIC
+    #include "MediaInfoDLL/MediaInfoDLL_Static.h"
+    #define MediaInfoNameSpace MediaInfoDLL
+#else
+    #include "MediaInfo/MediaInfo.h"
+    #define MediaInfoNameSpace MediaInfoLib
+#endif
+#include <MediaInfo/MediaInfo_Events.h>
 
 //---------------------------------------------------------------------------
 namespace MediaConch {
 
 class Core;
+class CheckerReport;
 class DaemonClient;
 class Policy;
 class XsltPolicyRule;
@@ -258,7 +270,8 @@ public:
     void reset_daemon_client();
 
     //Options
-    int test_mil_option(const std::string& key, std::string& value, std::string& report);
+    int  test_mil_option(const std::string& key, std::string& value, std::string& report);
+    bool mil_has_curl_enabled();
 
     // MediaConch
     int  mediaconch_get_plugins(std::vector<std::string>& plugins, std::string& error);
@@ -295,22 +308,15 @@ public:
     int  checker_file_information(int user, long id, Checker_FileInfo& info, std::string& error);
 
     // Output
-    int  checker_get_report(int user, const std::bitset<report_Max>& Report, format f,
-                            const std::vector<long>& files,
-                            const std::vector<size_t>& policies_ids,
-                            const std::vector<std::string>& policies_contents,
-                            const std::map<std::string, std::string>& options,
-                            Checker_ReportRes* result, std::string& error,
-                            const std::string* display_name = NULL,
-                            const std::string* display_content = NULL);
-    int checker_validate(int user, MediaConchLib::report report, const std::vector<long>& files,
-                         const std::vector<size_t>& policies_ids,
-                         const std::vector<std::string>& policies_contents,
-                         const std::map<std::string, std::string>& options,
-                         std::vector<Checker_ValidateRes*>& result, std::string& error);
+    int  checker_get_report(CheckerReport& c_report, Checker_ReportRes* result, std::string& error);
+    int  checker_validate(int user, MediaConchLib::report report, const std::vector<long>& files,
+                          const std::vector<size_t>& policies_ids,
+                          const std::vector<std::string>& policies_contents,
+                          const std::map<std::string, std::string>& options,
+                          std::vector<Checker_ValidateRes*>& result, std::string& error);
 
     //Clear
-    int remove_report(int user, const std::vector<long>& files, std::string& error);
+    int  checker_clear(int user, const std::vector<long>& files, std::string& error);
 
     // Policies
     //   Create policy
@@ -356,12 +362,6 @@ public:
     void               set_implementation_verbosity(const std::string& verbosity);
     const std::string& get_implementation_verbosity();
 
-    // Xsl Transformation
-    int  transform_with_xslt_file(const std::string& report, const std::string& file,
-                                  const std::map<std::string, std::string>& opts, std::string& result);
-    int  transform_with_xslt_memory(const std::string& report, const std::string& memory,
-                                    const std::map<std::string, std::string>& opts, std::string& result);
-
     // Configuration
     void               load_configuration();
     void               set_configuration_file(const std::string& file);
@@ -388,6 +388,9 @@ public:
     int load_system_policy();
     int load_existing_policy();
 
+    // Register Event callback
+    void register_log_callback(void (*log)(struct MediaInfo_Event_Log_0* Event));
+
 private:
     MediaConchLib (const MediaConchLib&);
 
