@@ -237,6 +237,38 @@ bool NoDatabaseReport::file_is_analyzed(int user, long id, std::string& err)
     return false;
 }
 
+//---------------------------------------------------------------------------
+int NoDatabaseReport::remove_file(int user, long id, std::string& err)
+{
+    err = std::string();
+    if (id >= 0 && id < (long)files_saved.size() && files_saved[id] &&
+        files_saved[id]->user == user)
+    {
+        delete files_saved[id];
+        files_saved[id] = NULL;
+        return 0;
+    }
+
+    err = "File not found";
+    return -1;
+}
+
+//---------------------------------------------------------------------------
+int NoDatabaseReport::remove_all_files(int user, std::string& err)
+{
+    err = std::string();
+    for (size_t id = 0; id < files_saved.size(); ++id)
+    {
+        if (!files_saved[id] || files_saved[id]->user != user)
+            continue;
+
+        delete files_saved[id];
+        files_saved[id] = NULL;
+    }
+
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 int NoDatabaseReport::add_file_generated_id(int user, long source_id, long generated_id, std::string& err)
 {
@@ -368,6 +400,25 @@ int NoDatabaseReport::remove_report(int user, long file_id, std::string& err)
     return 0;
 }
 
+//---------------------------------------------------------------------------
+int NoDatabaseReport::remove_all_reports(int user, std::string& err)
+{
+    err = std::string();
+    for (size_t id = 0; id < files_saved.size(); ++id)
+    {
+        if (!files_saved[id] || files_saved[id]->user != user)
+            continue;
+
+        std::map<long, std::vector<MC_Report*> >::iterator it = reports_saved.find(id);
+
+        if (it == reports_saved.end())
+            continue;
+
+        reports_saved.erase(it);
+    }
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 int NoDatabaseReport::report_is_registered(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
                                            const std::string& options, bool& registered, std::string& err)
