@@ -41,7 +41,7 @@ namespace MediaConch
     //**************************************************************************
     // Daemon
     //**************************************************************************
-    std::string Daemon::version = "17.04.0";
+    std::string Daemon::version = "17.05.0";
 
     //--------------------------------------------------------------------------
     Daemon::Daemon() : is_daemon(true), httpd(NULL), logger(NULL), watch_folder_user(NULL),
@@ -995,7 +995,7 @@ namespace MediaConch
             files.push_back(id);
 
             std::string err;
-            if (d->MCL->remove_report(req->user, files, err) < 0)
+            if (d->MCL->checker_clear(req->user, files, err) < 0)
                 FUN_CMD_NOK_ARR(res, err, id)
 
             res.ok.push_back(id);
