@@ -7,14 +7,17 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <QMainWindow>
+#include <QFileInfo>
+#include <QString>
+#include <map>
+#include <list>
+
 #include "Common/Core.h"
 #include "workerfiles.h"
 #include "uisettings.h"
 #include "DatabaseUi.h"
 
-#include <QMainWindow>
-#include <QFileInfo>
-#include <QString>
 
 namespace Ui {
     class MainWindow;
@@ -33,10 +36,12 @@ class CheckerWindow;
 class PoliciesWindow;
 class PublicPoliciesWindow;
 class DisplayWindow;
+class DatabaseWindow;
 class VerbositySpinbox;
 class PolicyCombobox;
 class DisplayCombobox;
 class FileRegistered;
+class WebView;
 
 class MainWindow : public QMainWindow
 {
@@ -52,6 +57,7 @@ public:
         RUN_CHECKER_VIEW,
         RUN_POLICIES_VIEW,
         RUN_DISPLAY_VIEW,
+        RUN_DATABASE_VIEW,
         RUN_SETTINGS_VIEW,
         RUN_PUBLIC_POLICIES_VIEW,
     };
@@ -61,7 +67,11 @@ public:
     int                         add_file_to_list(const QString& file, const QString& path, const QString& policy,
                                                  const QString& display,
                                                  const QString& verbosity, bool fixer, bool, std::string& err);
-    void                        remove_file_to_list(const QString& file);
+    int                         add_file_to_list(long id, std::string& err);
+    int                         add_attachment_to_list(const QString& file, int policy, int display,
+                                                       int verbosity, std::string& err);
+    void                        remove_file_to_list(long file_id);
+    void                        remove_all_files_to_list();
     void                        update_policy_of_file_in_list(long file_id, const QString& policy);
     int                         analyze_force_file_to_list(long id, std::string& err);
     void                        clear_file_list();
@@ -72,12 +82,11 @@ public:
     void                        set_str_msg_to_status_bar(const std::string& message);
     void                        clear_msg_in_status_bar();
     void                        drag_and_drop_files_action(const QStringList& files);
+    bool                        mil_has_curl_enabled();
 
     // Helpers
     void                        set_widget_to_layout(QWidget* w);
     void                        remove_widget_from_layout(QWidget* w);
-    int                         transform_with_xslt_file(const std::string& report, const std::string& file, std::string& result);
-    int                         transform_with_xslt_memory(const std::string& report, const std::string& memory, std::string& result);
     int                         analyze(const std::vector<std::string>& files, bool with_fixer, bool force,
                                         std::vector<long>& files_id, std::string& err);
     int                         is_analyze_finished(const std::vector<std::string>& files,
@@ -109,12 +118,16 @@ public:
     void                        policies_selected();
     void                        public_policies_selected();
     void                        display_selected();
+    void                        database_selected();
     void                        settings_selected();
     void                        add_default_displays();
     void                        get_implementation_report(long file_id, QString& report, std::string& err,
                                                           int *display=NULL, int *verbosity=NULL);
     int                         validate_policy(long file_id, QString& report, std::string& err, int policy=-1, int *display=NULL);
+    int                         checker_clear(long id, QString& err);
+    int                         checker_clear(QString& err);
     int                         checker_file_from_id(long id, std::string& file, std::string& err);
+    int                         checker_file_information(long id, MediaConchLib::Checker_FileInfo& file, std::string& err);
 
     void                        add_policy_to_list(const QString& policy);
     void                        clear_policy_list();
@@ -168,7 +181,6 @@ public:
     FileRegistered*             get_file_registered_from_file(const std::string& file);
     FileRegistered*             get_file_registered_from_id(long file_id);
     std::string                 get_filename_from_registered_file_id(long file_id);
-    void                        remove_file_registered_from_file(const std::string& file);
 
     void                        create_policy_from_file(const FileRegistered* file);
 
@@ -177,7 +189,9 @@ public:
 
     int                         get_policies(const std::string&, MediaConchLib::Get_Policies&, QString& err);
     QString                     get_local_folder() const;
-    void                        get_registered_files(std::map<std::string, FileRegistered>& files);
+    void                        get_registered_files(std::map<std::string, FileRegistered*>& files);
+
+    void                        checker_list(std::vector<long>& files, QString& error);
 
     // Display related
     std::vector<QString>&       get_displays();
@@ -188,9 +202,11 @@ public:
 
     UiSettings&                 get_settings();
 
-    const map<string, list<string> >* providePolicyExistingType() const { return &Policies::existing_type; }
-    const list<Policies::validatorType>* providePolicyExistingValidator() const { return &Policies::existing_validator; }
-    const list<string>* providePolicyExistingXsltOperator() const { return &Policies::existing_xsltOperator; }
+    const std::map<std::string, std::list<std::string> >* providePolicyExistingType() const { return &Policies::existing_type; }
+    const std::list<Policies::validatorType>* providePolicyExistingValidator() const { return &Policies::existing_validator; }
+    const std::list<std::string>* providePolicyExistingXsltOperator() const { return &Policies::existing_xsltOperator; }
+
+    WebView*                      web_view;
 
 private:
     Ui::MainWindow *ui;
@@ -205,12 +221,15 @@ private:
     UiSettings                    uisettings;
     Run_View                      current_view;
 
+    long                          user;
+
     // Visual elements
     QVBoxLayout*                Layout;
     CheckerWindow*              checkerView;
     PoliciesWindow*             policiesView;
     PublicPoliciesWindow*       publicPoliciesView;
     DisplayWindow*              displayView;
+    DatabaseWindow*             databaseView;
     SettingsWindow*             settingsView;
 
     void                        create_and_configure_ui_database();
@@ -221,11 +240,12 @@ private:
     void                        createPoliciesView();
     void                        createPublicPoliciesView();
     void                        createDisplayView();
+    void                        createDatabaseView();
     void                        createSettingsView();
 
     void                        fill_display_used(int *policy_i,
                                                   std::string& display_name, std::string& display_content,
-                                                  const std::string*& dname, const std::string*& dcontent,
+                                                  std::string*& dname, std::string*& dcontent,
                                                   FileRegistered* fr);
     void                        fill_options_for_report(std::map<std::string, std::string>& opts, int *verbosity_p);
 
@@ -250,6 +270,7 @@ public Q_SLOTS:
     void on_actionPolicies_triggered();
     void on_actionPublicPolicies_triggered();
     void on_actionDisplay_triggered();
+    void on_actionDatabase_triggered();
     void on_actionSettings_triggered();
 
     //Help
@@ -259,6 +280,8 @@ public Q_SLOTS:
     void on_actionDataFormat_triggered();
 
     bool close();
+    void loadFinished_Custom(bool ok);
+    void loadProgress_Custom(int progress);
 };
 
 }
