@@ -6,15 +6,9 @@
 
 #include "settingswindow.h"
 #include "mainwindow.h"
+#include "WebView.h"
 #include "WebPage.h"
 #include "progressbar.h"
-#if defined(WEB_MACHINE_ENGINE)
-#include <QWebEnginePage>
-#include <QWebChannel>
-#endif
-#if defined(WEB_MACHINE_KIT)
-#include <QWebFrame>
-#endif
 #include <QFile>
 #include <QProgressBar>
 
@@ -24,13 +18,12 @@ namespace MediaConch {
 // Constructor / Desructor
 //***************************************************************************
 
-SettingsWindow::SettingsWindow(MainWindow *p) : parent(p), settings_view(NULL), progress_bar(NULL)
+SettingsWindow::SettingsWindow(MainWindow *p) : CommonWebWindow(p)
 {
 }
 
 SettingsWindow::~SettingsWindow()
 {
-    clear_visual_elements();
 }
 
 //***************************************************************************
@@ -38,77 +31,29 @@ SettingsWindow::~SettingsWindow()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-void SettingsWindow::create_settings_finished(bool ok)
+void SettingsWindow::create_web_view_finished()
 {
-    if (!settings_view || !ok)
-        return;
-
-    add_save_report_path_to_js_input((WebPage *)settings_view->page());
-    add_load_files_path_to_js_input((WebPage *)settings_view->page());
-    add_save_policy_path_to_js_input((WebPage *)settings_view->page());
-    add_load_policy_path_to_js_input((WebPage *)settings_view->page());
-    add_save_display_path_to_js_input((WebPage *)settings_view->page());
-    add_load_display_path_to_js_input((WebPage *)settings_view->page());
-
-    if (progress_bar)
-    {
-        parent->remove_widget_from_layout(progress_bar);
-        delete progress_bar;
-        progress_bar = NULL;
-    }
-
-    settings_view->show();
-    parent->set_widget_to_layout(settings_view);
+    add_logged_to_js_input((WebPage *)main_window->web_view->page());
+    add_save_report_path_to_js_input((WebPage *)main_window->web_view->page());
+    add_load_files_path_to_js_input((WebPage *)main_window->web_view->page());
+    add_save_policy_path_to_js_input((WebPage *)main_window->web_view->page());
+    add_load_policy_path_to_js_input((WebPage *)main_window->web_view->page());
+    add_save_display_path_to_js_input((WebPage *)main_window->web_view->page());
+    add_load_display_path_to_js_input((WebPage *)main_window->web_view->page());
 }
 
 //---------------------------------------------------------------------------
 void SettingsWindow::display_settings()
 {
-    clear_visual_elements();
-
-    progress_bar = new ProgressBar(parent);
-    parent->set_widget_to_layout(progress_bar);
-    progress_bar->get_progress_bar()->setValue(0);
-    progress_bar->show();
-
-    QString html;
-    create_html(html);
-
-    QUrl url = QUrl("qrc:/html");
-    if (!url.isValid())
-        return;
-
-    settings_view = new WebView(parent);
-    settings_view->hide();
-
-    WebPage* page = new WebPage(parent, settings_view);
-    settings_view->setPage(page);
-
-    QObject::connect(settings_view, SIGNAL(loadProgress(int)), progress_bar->get_progress_bar(), SLOT(setValue(int)));
-    QObject::connect(settings_view, SIGNAL(loadFinished(bool)), this, SLOT(create_settings_finished(bool)));
-
-#if defined(WEB_MACHINE_ENGINE)
-    QWebChannel *channel = new QWebChannel(page);
-    page->setWebChannel(channel);
-    channel->registerObject("webpage", page);
-    settings_view->setHtml(html.toUtf8(), url);
-#endif
-#if defined(WEB_MACHINE_KIT)
-    settings_view->setContent(html.toUtf8(), "text/html", url);
-#endif
+    display_html();
 }
 
-
 //---------------------------------------------------------------------------
 void SettingsWindow::create_html(QString& html)
 {
     QString settings;
     create_html_settings(settings);
-
-    QString base;
-    create_html_base(base, settings);
-
-    html = QString(base);
+    create_html_base(html, settings);
 }
 
 //---------------------------------------------------------------------------
@@ -126,41 +71,12 @@ void SettingsWindow::create_html_settings(QString& settings)
 //---------------------------------------------------------------------------
 void SettingsWindow::create_html_base(QString& base, const QString& settings)
 {
-    QFile template_html(":/base.html");
-    template_html.open(QIODevice::ReadOnly | QIODevice::Text);
-    base = QString(template_html.readAll());
-    template_html.close();
-
     set_webmachine_script_in_template(base);
     change_qt_scripts_in_template(base);
     change_checker_in_template(base, settings);
     remove_result_in_template(base);
 }
 
-//---------------------------------------------------------------------------
-void SettingsWindow::clear_visual_elements()
-{
-    if (settings_view)
-    {
-        parent->remove_widget_from_layout(settings_view);
-#if defined(WEB_MACHINE_ENGINE)
-        WebPage* page = (WebPage*)settings_view->page();
-        QWebChannel *channel = page ? page->webChannel() : NULL;
-        if (channel)
-            channel->deregisterObject(page);
-#endif
-        delete settings_view;
-        settings_view = NULL;
-    }
-
-    if (progress_bar)
-    {
-        parent->remove_widget_from_layout(progress_bar);
-        delete progress_bar;
-        progress_bar = NULL;
-    }
-}
-
 //***************************************************************************
 // HELPER
 //***************************************************************************
@@ -187,12 +103,12 @@ void SettingsWindow::create_policy_options(QString& policies)
     MediaConchLib::Get_Policies p;
     QString err;
 
-    parent->get_policies("JSON", p, err);
+    main_window->get_policies("JSON", p, err);
 
     QString system_policy;
     QString user_policy;
 
-    std::string policy_str = parent->get_settings().get_default_policy();
+    std::string policy_str = main_window->get_settings().get_default_policy();
     int selected_policy;
     if (policy_str == "last")
         selected_policy = -2;
@@ -247,14 +163,14 @@ void SettingsWindow::create_displays_options(QString& displays)
     QString system_display;
     QString user_display;
 
-    std::string display_str = parent->get_settings().get_default_display();
+    std::string display_str = main_window->get_settings().get_default_display();
     int selected_display;
     if (display_str == "last")
         selected_display = -1;
     else
-        selected_display = parent->get_display_index_by_filename(display_str);
+        selected_display = main_window->get_display_index_by_filename(display_str);
 
-    const std::vector<QString>& displays_list = parent->get_displays();
+    const std::vector<QString>& displays_list = main_window->get_displays();
     for (size_t i = 0; i < displays_list.size(); ++i)
     {
         QFileInfo file(displays_list[i]);
@@ -293,7 +209,7 @@ void SettingsWindow::create_displays_options(QString& displays)
 //---------------------------------------------------------------------------
 void SettingsWindow::create_verbosity_options(QString& verbosity)
 {
-    int selected_verbosity = parent->get_settings().get_default_verbosity();
+    int selected_verbosity = main_window->get_settings().get_default_verbosity();
 
     if (selected_verbosity == -1)
         verbosity += QString("<option selected=\"selected\" value=\"-1\">Last verbosity used</option>");
@@ -422,10 +338,18 @@ void SettingsWindow::set_webmachine_script_in_template(QString& html)
         html.replace(pos, reg.matchedLength(), machine);
 }
 
+//---------------------------------------------------------------------------
+void SettingsWindow::add_logged_to_js_input(WebPage *page)
+{
+    std::string token_str = main_window->get_settings().get_mco_token();
+    QString token = QString().fromUtf8(token_str.c_str(), token_str.length());
+    page->use_javascript(QString("set_logged_status('%1');").arg(token));
+}
+
 //---------------------------------------------------------------------------
 void SettingsWindow::add_save_report_path_to_js_input(WebPage *page)
 {
-    std::string selected_save_report_str = parent->get_settings().get_default_save_report_path();
+    std::string selected_save_report_str = main_window->get_settings().get_default_save_report_path();
     QString selected_save_report = QString().fromUtf8(selected_save_report_str.c_str(), selected_save_report_str.length());
     page->use_javascript(QString("set_save_report_selected('%1');").arg(selected_save_report));
 }
@@ -433,7 +357,7 @@ void SettingsWindow::add_save_report_path_to_js_input(WebPage *page)
 //---------------------------------------------------------------------------
 void SettingsWindow::add_load_files_path_to_js_input(WebPage *page)
 {
-    std::string selected_load_files_str = parent->get_settings().get_default_load_files_path();
+    std::string selected_load_files_str = main_window->get_settings().get_default_load_files_path();
     QString selected_load_files = QString().fromUtf8(selected_load_files_str.c_str(), selected_load_files_str.length());
     page->use_javascript(QString("set_load_files_selected('%1');").arg(selected_load_files));
 }
@@ -441,7 +365,7 @@ void SettingsWindow::add_load_files_path_to_js_input(WebPage *page)
 //---------------------------------------------------------------------------
 void SettingsWindow::add_save_policy_path_to_js_input(WebPage *page)
 {
-    std::string selected_save_policy_str = parent->get_settings().get_default_save_policy_path();
+    std::string selected_save_policy_str = main_window->get_settings().get_default_save_policy_path();
     QString selected_save_policy = QString().fromUtf8(selected_save_policy_str.c_str(), selected_save_policy_str.length());
     page->use_javascript(QString("set_save_policy_selected('%1');").arg(selected_save_policy));
 }
@@ -449,7 +373,7 @@ void SettingsWindow::add_save_policy_path_to_js_input(WebPage *page)
 //---------------------------------------------------------------------------
 void SettingsWindow::add_load_policy_path_to_js_input(WebPage *page)
 {
-    std::string selected_load_policy_str = parent->get_settings().get_default_load_policy_path();
+    std::string selected_load_policy_str = main_window->get_settings().get_default_load_policy_path();
     QString selected_load_policy = QString().fromUtf8(selected_load_policy_str.c_str(), selected_load_policy_str.length());
     page->use_javascript(QString("set_load_policy_selected('%1');").arg(selected_load_policy));
 }
@@ -457,7 +381,7 @@ void SettingsWindow::add_load_policy_path_to_js_input(WebPage *page)
 //---------------------------------------------------------------------------
 void SettingsWindow::add_save_display_path_to_js_input(WebPage *page)
 {
-    std::string selected_save_display_str = parent->get_settings().get_default_save_display_path();
+    std::string selected_save_display_str = main_window->get_settings().get_default_save_display_path();
     QString selected_save_display = QString().fromUtf8(selected_save_display_str.c_str(), selected_save_display_str.length());
     page->use_javascript(QString("set_save_display_selected('%1');").arg(selected_save_display));
 }
@@ -465,7 +389,7 @@ void SettingsWindow::add_save_display_path_to_js_input(WebPage *page)
 //---------------------------------------------------------------------------
 void SettingsWindow::add_load_display_path_to_js_input(WebPage *page)
 {
-    std::string selected_load_display_str = parent->get_settings().get_default_load_display_path();
+    std::string selected_load_display_str = main_window->get_settings().get_default_load_display_path();
     QString selected_load_display = QString().fromUtf8(selected_load_display_str.c_str(), selected_load_display_str.length());
     page->use_javascript(QString("set_load_display_selected('%1');").arg(selected_load_display));
 }
